<?php
/* $Id: russian-windows-1251.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */

/**
 * Translated by Gosha Sakovich <gt2 at users.sourceforge.net>
 *               Artyom Rabzonov <tyomych at gmx.net>
 *               Nicolay Zakharov <info at melody.org.ru> 16-Dec-2002
 *               (nobody) 2004-09-18
 */

$charset = 'windows-1251';
$text_dir = 'ltr';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
//   8.417-2002
$byteUnits = array('', '', '', '', '', '', '');

$day_of_week = array('', '', '', '', '', '', '');
$month = array('', '', '', '', '', '', '', '', '', '', '', '');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%B %d %Y ., %H:%M';
$timespanfmt = '%s , %s , %s   %s ';

$strAbortedClients = '';
$strAccessDenied = '  ';
$strAccessDeniedCreateConfig = '  -   .       %1$s %2$s.';
$strAccessDeniedExplanation = 'phpMyAdmin     MySQL,    .   ,     config.inc.php.';
$strAction = '';
$strAddAutoIncrement = '  AUTO_INCREMENT';
$strAddClause = ' %s';
$strAddConstraints = ' ';
$strAddDeleteColumn = '/  ';
$strAddDeleteRow = '/  ';
$strAddFields = ' %s ()';
$strAddHeaderComment = '     ( : \\n)';
$strAddIntoComments = '  ';
$strAddNewField = '  ';
$strAddPrivilegesOnDb = '    ';
$strAddPrivilegesOnTbl = '     ';
$strAddSearchConditions = '   (   "where"):';
$strAddToIndex = '  &nbsp;%s&nbsp;()';
$strAddUser = '  ';
$strAddUserMessage = '   .';
$strAdministration = '';
$strAffectedRows = ' :';
$strAfter = ' %s';
$strAfterInsertBack = '';
$strAfterInsertNewInsert = '  ';
$strAfterInsertNext = '  ';
$strAfterInsertSame = '   ';
$strAll = '';
$strAllTableSameWidth = '     ?';
$strAlterOrderBy = '  ';
$strAnalyzeTable = ' ';
$strAnd = '';
$strAndThen = ' ';
$strAnIndex = '    %s';
$strAny = '';
$strAnyHost = ' ';
$strAnyUser = ' ';
$strApproximateCount = '  . . FAQ 3.11';
$strAPrimaryKey = '     %s';
$strArabic = '';
$strArmenian = '';
$strAscending = ' ';
$strAtBeginningOfTable = '  ';
$strAtEndOfTable = '  ';
$strAttr = '';
$strAutodetect = '';
$strAutomaticLayout = ' ';

$strBack = '';
$strBaltic = '';
$strBeginCut = 'BEGIN CUT';
$strBeginRaw = 'BEGIN RAW';
$strBinary = '  ';
$strBinaryDoNotEdit = '   -   ';
$strBinLogEventType = ' ';
$strBinLogInfo = '';
$strBookmarkAllUsers = '     ';
$strBookmarkCreated = ' %s ';
$strBookmarkDeleted = '  .';
$strBookmarkLabel = '';
$strBookmarkQuery = '  SQL-';
$strBookmarkReplace = '     .';
$strBookmarkThis = '   SQL-';
$strBookmarkView = ' ';
$strBrowse = '';
$strBrowseDistinctValues = '  ';
$strBulgarian = '';
$strBzError = 'phpMyAdmin     -   Bz2 extension    PHP.     <code>$cfg[\'BZipDump\']</code>     phpMyAdmin  <code>FALSE</code>.     Bz2-,    PHP.  PHP bug report %s    .';
$strBzip = '  bzip';

$strCalendar = '';
$strCannotLogin = '   MySQL';
$strCantLoad = '    %s,<br />  PHP, ';
$strCantLoadRecodeIconv = '   iconv  recode,    .  php-          phpMyAdmin.';
$strCantRenameIdxToPrimary = '    PRIMARY!';
$strCantUseRecodeIconv = '   iconv :  libiconv,  recode_string,     extension reports.  php-.';
$strCardinality = ' ';
$strCaseInsensitive = '  ';
$strCaseSensitive = '   ';
$strCentralEuropean = '-';
$strChange = '';
$strChangeCopyMode = '        ...';
$strChangeCopyModeCopy = '...  .';
$strChangeCopyModeDeleteAndReload = ' ...        .';
$strChangeCopyModeJustDelete = ' ...     .';
$strChangeCopyModeRevoke = ' ...         .';
$strChangeCopyUser = '  /  ';
$strChangeDisplay = '   ';
$strChangePassword = ' ';
$strCharset = '';
$strCharsetOfFile = ' :';
$strCharsets = '';
$strCharsetsAndCollations = '  ';
$strCheckAll = ' ';
$strCheckOverhead = '  ';
$strCheckPrivs = ' ';
$strCheckPrivsLong = '    &quot;%s&quot;.';
$strCheckTable = ' ';
$strChoosePage = '   ';
$strColComFeat = '  ';
$strCollation = '';
$strColumnNames = ' ';
$strColumnPrivileges = ',   ';
$strCommand = '';
$strComments = '';
$strCommentsForTable = '  ';
$strCompatibleHashing = 'MySQL&nbsp;4.0 ';
$strCompleteInserts = ' ';
$strCompression = '';
$strCompressionWillBeDetected = '      : %s';
$strConfigDefaultFileError = '   - : "%1$s"';
$strConfigFileError = 'phpMyAdmin       !  <br />  -  .<br />   (config.inc.php)   .      -  .    -   ';
$strConfigureTableCoord = '   %s';
$strConnectionError = ' :  .';
$strConnections = '';
$strConstraintsForDumped = 'Constraints for dumped tables';
$strConstraintsForTable = 'Constraints for table';
$strCookiesRequired = 'Cookies      .';
$strCopy = '';
$strCopyDatabaseOK = ' %s    %s';
$strCopyTable = '   ( <b>.</b>):';
$strCopyTableOK = ' %s    %s.';
$strCopyTableSameNames = '        !';
$strCouldNotKill = 'phpMyAdmin    thread %s. ,   .';
$strCreate = '';
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE  ';
$strCreateIndex = '  &nbsp;%s&nbsp;';
$strCreateIndexTopic = '  ';
$strCreateNewDatabase = '  ';
$strCreateNewTable = '     %s';
$strCreatePage = '  ';
$strCreatePdfFeat = ' PDF-';
$strCreateUserDatabase = '   ';
$strCreateUserDatabaseName = '    -     ';
$strCreateUserDatabaseNone = ' ';
$strCreateUserDatabaseWildcard = '     (username\_%)';
$strCreationDates = '// ';
$strCriteria = '';
$strCroatian = '';
$strCSV = 'CSV';
$strCSVImportOptions = ' CSV';
$strCSVOptions = ' CSV';
$strCyrillic = '';
$strCzech = '';
$strCzechSlovak = '';

$strDanish = '';
$strData = '';
$strDatabase = ' ';
$strDatabaseEmpty = '    !';
$strDatabaseExportOptions = '   ';
$strDatabaseHasBeenDropped = '  %s  .';
$strDatabaseNoTable = '    !';
$strDatabases = ' ';
$strDatabasesDropped = '%s    .';
$strDatabasesStats = '  ';
$strDatabasesStatsDisable = ' ';
$strDatabasesStatsEnable = ' ';
$strDatabasesStatsHeavyTraffic = ':          -   MySQL.';
$strDataDict = ' ';
$strDataOnly = ' ';
$strDataPages = '  ';
$strDBComment = ' : ';
$strDBCopy = '  ';
$strDbPrivileges = ' ,    ';
$strDBRename = '   ';
$strDbSpecific = '  ';
$strDefault = ' ';
$strDefaultValueHelp = '           ,   : a';
$strDefragment = ' ';
$strDelayedInserts = '  ';
$strDelete = '';
$strDeleteAndFlush = '     .';
$strDeleteAndFlushDescr = '  ,       .';
$strDeleted = '  ';
$strDeletedRows = '   :';
$strDeleteNoUsersSelected = '    !';
$strDeleting = ' %s';
$strDelimiter = '';
$strDelOld = '      ,    .     ?';
$strDescending = ' ';
$strDescription = '';
$strDictionary = '';
$strDirtyPages = ' ';
$strDisabled = '';
$strDisableForeignChecks = '   ';
$strDisplayFeat = '  ';
$strDisplayOrder = ' :';
$strDisplayPDF = ' PDF-';
$strDoAQuery = ' "  " ( : "%")';
$strDocu = '';
$strDoYouReally = '   ';
$strDrop = '';
$strDropDatabaseStrongWarning = '       ?';
$strDropUsersDb = ' ,        .';
$strDumpingData = '  ';
$strDumpSaved = '    %s.';
$strDumpXRows = ' %s ,   %s.';
$strDynamic = '';

$strEdit = '';
$strEditPDFPages = ' PDF-';
$strEditPrivileges = ' ';
$strEffective = '';
$strEmpty = '';
$strEmptyResultSet = 'MySQL    (..  ).';
$strEnabled = '';
$strEncloseInTransaction = '  ';
$strEnd = '';
$strEndCut = 'END CUT';
$strEndRaw = 'END RAW';
$strEngines = '';
$strEnglish = '';
$strEnglishPrivileges = ' :  MySQL  - ';
$strError = '';
$strErrorInZipFile = '  ZIP-:';
$strErrorRenamingTable = '    %1$s  %2$s';
$strEsperanto = '';
$strEstonian = '';
$strExcelEdition = 'Excel-';
$strExcelOptions = ' Excel';
$strExecuteBookmarked = '  ';
$strExplain = ' SQL';
$strExport = '';
$strExtendedInserts = ' ';
$strExtra = '';

$strFailedAttempts = ' ';
$strField = '';
$strFieldHasBeenDropped = ' %s  ';
$strFields = '';
$strFieldsEmpty = '   ! ';
$strFieldsEnclosedBy = '  ';
$strFieldsEscapedBy = ' ';
$strFieldsTerminatedBy = ' ';
$strFileAlreadyExists = ' %s    ,      .';
$strFileCouldNotBeRead = '    ';
$strFileNameTemplate = '  ';
$strFileNameTemplateDescriptionDatabase = '  ';
$strFileNameTemplateDescriptionServer = ' ';
$strFileNameTemplateDescriptionTable = ' ';
$strFileNameTemplateRemember = ' ';
$strFileToImport = '  ';
$strFixed = '';
$strFlushPrivilegesNote = ': phpMyAdmin        MySQL.        ,   ,     .      %s %s   .';
$strFlushQueryCache = '  ';
$strFlushTable = '   ("FLUSH")';
$strFlushTables = '  ';
$strFontSize = ' ';
$strFormat = '';
$strFormEmpty = '   !';
$strFullText = '';
$strFunction = '';
$strFunctions = '';

$strGenBy = '';
$strGeneralRelationFeat = '  ';
$strGenerate = '';
$strGeneratePassword = ' ';
$strGenTime = ' ';
$strGeorgian = '';
$strGerman = '';
$strGlobal = 'global';
$strGlobalPrivileges = ' ';
$strGlobalValue = ' ';
$strGo = '';
$strGrantOption = '';
$strGreek = '';
$strGzip = '  gzip';

$strHandler = '';
$strHasBeenAltered = ' .';
$strHasBeenCreated = ' .';
$strHaveToShow = '        ';
$strHebrew = '';
$strHexForBinary = '  (hexadecimal)  ';
$strHome = ' ';
$strHomepageOfficial = '  phpMyAdmin';
$strHost = '';
$strHostEmpty = '  !';
$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLExcelOptions = '   Microsoft Excel 2000';
$strHTMLWord = 'Microsoft Word 2000';
$strHTMLWordOptions = '   Microsoft Word 2000';
$strHungarian = '';

$strIcelandic = '';
$strId = 'ID';
$strIdxFulltext = '';
$strIgnore = '';
$strIgnoreDuplicates = '  ';
$strIgnoreInserts = ' ';
$strImport = '';
$strImportFiles = ' ';
$strImportFormat = '  ';
$strImportSuccessfullyFinished = '  ,  : %d.';
$strIndex = '';
$strIndexes = '';
$strIndexHasBeenDropped = ' %s  ';
$strIndexName = ' &nbsp;:';
$strIndexType = ' &nbsp;:';
$strIndexWarningMultiple = '  %s     `%s`';
$strIndexWarningTable = '    `%s`';
$strInnoDBDataFilePath = ' ';
$strInnoDBDataHomeDir = '   ';
$strInnoDBDataHomeDirDesc = '         InnoDB.';
$strInnoDBPages = '';
$strInnodbStat = ' InnoDB';
$strInsecureMySQL = '     ( root  ),      MySQL ( ).  MySQL       ,   ,         .';
$strInsert = '';
$strInsertAsNewRow = '  ';
$strInsertedRowId = ' id :';
$strInsertedRows = ' :';
$strInternalNotNecessary = '*    ,      InnoDB.';
$strInternalRelations = ' ';
$strInUse = '';
$strInvalidColumn = '   (%s)';
$strInvalidColumnCount = '     .';
$strInvalidCSVFieldCount = '     CSV-   %d.';
$strInvalidCSVFormat = '   CSV-   %d.';
$strInvalidCSVParameter = '   CSV: %s';
$strInvalidDatabase = '  '; 
$strInvalidFieldAddCount = '      .';
$strInvalidFieldCount = '       .';
$strInvalidRowNumber = ' %d     .';
$strInvalidTableName = '  ';

$strJapanese = '';
$strJoins = '';
$strJumpToDB = '   &quot;%s&quot;.';
$strJustDelete = '     .';
$strJustDeleteDescr = '&quot;&quot;            .';

$strKeepPass = '  ';
$strKeyCache = ' ';
$strKeyname = ' ';
$strKill = '';
$strKorean = '';

$strLandscape = '';
$strLanguage = '';
$strLanguageFileNotFound = ' : "%1$s"  .';
$strLanguageUnknown = ' : %1$s.';
$strLaTeX = 'LaTeX';
$strLatexCaption = ' ';
$strLatexContent = '  __TABLE__';
$strLatexContinued = '()';
$strLatexContinuedCaption = '  ';
$strLatexIncludeCaption = '  ';
$strLaTeXOptions = ' LaTeX';
$strLatexStructure = '  __TABLE__';
$strLatvian = '';
$strLDI = 'CSV  LOAD DATA';
$strLDIImportOptions = '   CSV  LOAD DATA';
$strLengthSet = '/*';
$strLimitNumRows = '  ';
$strLinesTerminatedBy = ' ';
$strLinkNotFound = '  ';
$strLinksTo = ' ';
$strLithuanian = '';
$strLocalhost = '';
$strLocationTextfile = '  ';
$strLogin = '  ';
$strLoginInformation = ' ';
$strLogout = '  ';
$strLogPassword = ':';
$strLogServer = '';
$strLogUsername = ':';

$strMaximalQueryLength = '   ';
$strMaximumSize = ' : %s%s';
$strMIME_available_mime = ' MIME-';
$strMIME_available_transform = ' ';
$strMIME_description = '';
$strMIME_MIMEtype = 'MIME-';
$strMIME_nodescription = '     .<br />,     %s.';
$strMIME_transformation = ' ';
$strMIME_transformation_note = '        MIME-   %s %s';
$strMIME_transformation_options = ' ';
$strMIME_transformation_options_note = ',    ,   : \'a\', 100, b,\'c\'...<br />    ("\")  ("\'"),   ( \'\\\\xyz\' or \'a\\\'b\').';
$strMIME_without = 'MIME-,  ,     ';
$strMIMETypesForTable = 'MIME- ';
$strModifications = '  ';
$strModify = '';
$strModifyIndexTopic = ' ';
$strMoveTable = '   ( <b>.</b>):';
$strMoveTableOK = ' %s    %s.';
$strMoveTableSameNames = '      !';
$strMultilingual = '';
$strMySQLCharset = 'MySQL-';
$strMysqlClientVersion = ' MySQL-';
$strMySQLConnectionCollation = '   MySQL';
$strMySQLSaid = ' MySQL: ';
$strMySQLShowProcess = ' ';
$strMySQLShowStatus = ' ';
$strMySQLShowVars = '  ';

$strName = '';
$strNext = '';
$strNo = '';
$strNoDatabases = ' ';
$strNoDatabasesSelected = '    .';
$strNoDataReceived = '    .           ,     PHP. . FAQ 1.16';
$strNoDescription = ' ';
$strNoDropDatabases = ' " " .';
$strNoExplain = '  SQL';
$strNoFilesFoundInZip = '  ZIP-  !';
$strNoFrames = '  phpMyAdmin     <b></b>.';
$strNoIndex = '  !';
$strNoIndexPartsDefined = '   !';
$strNoModification = ' ';
$strNone = '';
$strNoOptions = '    ';
$strNoPassword = ' ';
$strNoPermission = '-       %s.';
$strNoPhp = ' PHP-';
$strNoPrivileges = ' ';
$strNoRights = '      !';
$strNoRowsSelected = '   ';
$strNoSpace = '       %s.';
$strNoTablesFound = '    .';
$strNotNumber = '  !';
$strNotOK = ' ';
$strNotSet = ' <b>%s</b>  ';
$strNoUsersFound = '  .';
$strNoValidateSQL = '  SQL';
$strNull = '';
$strNumberOfFields = ' ';
$strNumSearchResultsInTable = '%s ()   <i>%s</i>';
$strNumSearchResultsTotal = '<b>:</b> <i>%s</i> ()';
$strNumTables = '';

$strOK = '';
$strOpenDocumentText = 'Open Document Text';
$strOpenDocumentTextOptions = ' Open Document Text';
$strOpenNewWindow = '  phpMyAdmin';
$strOperations = '';
$strOperator = '';
$strOptimizeTable = ' ';
$strOr = '';
$strOverhead = ' ';
$strOverwriteExisting = ' () ()';

$strPageNumber = ' :';
$strPaperSize = ' ';
$strPartialImport = ' ';
$strPartialText = ' ';
$strPassword = '';
$strPasswordChanged = '  %s   .';
$strPasswordEmpty = ' !';
$strPasswordNotSame = '  !';
$strPDF = 'PDF';
$strPdfDbSchema = '  "%s" -  %s';
$strPdfInvalidTblName = ' "%s"  !';
$strPdfNoTables = ' ';
$strPDFOptions = ' PDF';
$strPDFReportExplanation = '( ,    )';
$strPerHour = ' ';
$strPerMinute = ' ';
$strPerSecond = ' ';
$strPersian = '';
$strPhoneBook = ' ';
$strPhp = ' PHP-';
$strPHP40203 = '   PHP 4.2.3,        -  (mbstring).  PHP bug report 19404.   PHP      phpMyAdmin.';
$strPHPVersion = ' PHP';
$strPmaDocumentation = '  phpMyAdmin';
$strPmaUriError = ' <tt>$cfg[\'PmaAbsoluteUri\']</tt>       !';
$strPolish = '';
$strPortrait = '';
$strPos1 = '';
$strPrevious = '';
$strPrimary = '';
$strPrimaryKeyHasBeenDropped = '   ';
$strPrimaryKeyName = '     PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b></b>   <b></b>  !)';
$strPrint = '';
$strPrintView = '  ';
$strPrintViewFull = ' (  )';
$strPrivDescAlter = '    .';
$strPrivDescCreateDb = '      .';
$strPrivDescCreateTbl = '   .';
$strPrivDescCreateTmpTable = '   .';
$strPrivDescDelete = '  .';
$strPrivDescDropDb = '  ';
$strPrivDescDropTbl = '  .';
$strPrivDescExecute = '   ;      MySQL.';
$strPrivDescFile = '      .';
$strPrivDescGrant = '        .';
$strPrivDescIndex = '    .';
$strPrivDescInsert = '    .';
$strPrivDescLockTables = '     .';
$strPrivDescMaxConnections = '  ,       .';
$strPrivDescMaxQuestions = '  ,       .';
$strPrivDescMaxUpdates = '  ,      ,      .';
$strPrivDescProcess3 = '    .';
$strPrivDescProcess4 = '      .';
$strPrivDescReferences = '     MySQL.';
$strPrivDescReload = '       .';
$strPrivDescReplClient = '      slaves / masters.';
$strPrivDescReplSlave = '   slaves.';
$strPrivDescSelect = '  .';
$strPrivDescShowDb = '      .';
$strPrivDescShutdown = '  .';
$strPrivDescSuper = ' ,      ;     ,          .';
$strPrivDescUpdate = '  .';
$strPrivDescUsage = ' .';
$strPrivileges = '';
$strPrivilegesReloaded = '   .';
$strProcedures = '';
$strProcesses = '';
$strProcesslist = ' ';
$strProtocolVersion = ' ';
$strPutColNames = '     ';

$strQBE = '&nbsp;&nbsp;';
$strQBEDel = '';
$strQBEIns = '';
$strQueryCache = ' ';
$strQueryFrame = ' ';
$strQueryOnDb = 'SQL-  <b>%s</b>:';
$strQueryResultsOperations = '   ';
$strQuerySQLHistory = ' SQL';
$strQueryStatistics = '<b> </b>:    %s     .';
$strQueryTime = '  %01.4f ';
$strQueryType = ' ';
$strQueryWindowLock = '     ';

$strReceived = '';
$strRecords = '';
$strReferentialIntegrity = '  :';
$strRefresh = '';
$strRelationalSchema = ' ';
$strRelationNotWorking = '       .     %s%s.';
$strRelations = '';
$strRelationsForTable = '  ';
$strRelationView = ' ';
$strReloadingThePrivileges = ' ';
$strReloadPrivileges = ' ';
$strRemoveSelectedUsers = '  ';
$strRenameDatabaseOK = '  %s   %s';
$strRenameTable = '  ';
$strRenameTableOK = ' %s    %s';
$strRepairTable = ' ';
$strReplaceNULLBy = ' NULL ';
$strReplaceTable = '     ';
$strReplication = '';
$strReset = '';
$strResourceLimits = '  ';
$strReType = '';
$strRevoke = '';
$strRevokeAndDelete = '        .';
$strRevokeAndDeleteDescr = '     USAGE    .';
$strRevokeMessage = '    %s';
$strRomanian = '';
$strRowLength = ' ';
$strRows = '';
$strRowsFrom = ' ';
$strRowSize = '   ';
$strRowsModeFlippedHorizontal = ' ( )';
$strRowsModeHorizontal = '';
$strRowsModeOptions = ' %s ,    %s ';
$strRowsModeVertical = '';
$strRowsStatistic = ' ';
$strRunning = ' %s';
$strRunQuery = ' ';
$strRunSQLQuery = ' SQL ()   %';
$strRunSQLQueryOnServer = ' SQL ()   %s';
$strRussian = '';

$strSave = '';
$strSaveOnServer = '     %s';
$strScaleFactorSmall = '         ';
$strSearch = '';
$strSearchFormTitle = '   ';
$strSearchInTables = ' ():';
$strSearchNeedle = '()  ()   ( "%") :';
$strSearchOption1 = '  ';
$strSearchOption2 = ' ';
$strSearchOption3 = ' ';
$strSearchOption4 = ' ';
$strSearchResultsFor = '  "<i>%s</i>" %s:';
$strSearchType = ':';
$strSecretRequired = '      (blowfish_secret).';
$strSelectADb = ',   ';
$strSelectAll = ' ';
$strSelectFields = '  ( ):';
$strSelectNumRows = ' ';
$strSelectTables = ' ()';
$strSend = '';
$strSent = '';
$strServer = '';
$strServerChoice = ' ';
$strServerNotResponding = '  ';
$strServers = '';
$strServerStatus = ' ';
$strServerStatusDelayedInserts = ' ';
$strServerStatusUptime = ' MySQL   %s.    %s.';
$strServerTabVariables = '';
$strServerTrafficNotes = '<b></b>:        MySQL     .';
$strServerVars = '   ';
$strServerVersion = ' ';
$strSessionValue = ' ';
$strSetEnumVal = '   "enum"  "set",     : \'a\',\'b\',\'c\'...<br />       ("\"")    ("\'")   ,       (, \'\\\\xyz\'  \'a\\\'b\').';
$strShow = '';
$strShowAll = ' ';
$strShowColor = ' ';
$strShowDatadictAs = '  ';
$strShowFullQueries = '  ';
$strShowGrid = ' ';
$strShowingRecords = '  ';
$strShowOpenTables = '  ';
$strShowPHPInfo = '   PHP';
$strShowSlaveHosts = '  ';
$strShowSlaveStatus = '  ';
$strShowStatusCreated_tmp_disk_tablesDescr = '     ,     .   Created_tmp_disk_tables , ,     tmp_table_size,      ,     .';
$strShowStatusCreated_tmp_filesDescr = '    mysqld.';
$strShowStatusCreated_tmp_tablesDescr = '     ,     .';
$strShowStatusDelayed_errorsDescr = '     INSERT DELAYED ,    -  (, -  ).';
$strShowStatusDelayed_insert_threadsDescr = '  - INSERT DELAYED.       INSERT DELAYED   .';
$strShowStatusDelayed_writesDescr = ' ,  INSERT DELAYED.';
$strShowStatusFlush_commandsDescr  = '   FLUSH.';
$strShowStatusHandler_commitDescr = '   COMMIT.';
$strShowStatusHandler_deleteDescr = '    .';
$strShowStatusHandler_read_firstDescr = '     .    , ,   ,      , , SELECT col1 FROM foo, ,  col1 .';
$strShowStatusHandler_read_keyDescr = '    ,   .      ,        .';
$strShowStatusHandler_read_nextDescr = '         .    ,         .        .';
$strShowStatusHandler_read_prevDescr = '         .       ORDER BY ... DESC.';
$strShowStatusHandler_read_rnd_nextDescr = '        .    ,     .   ,              .';
$strShowStatusHandler_read_rndDescr = '    ,    .   ,    ,   .       MySQL              .';
$strShowStatusHandler_rollbackDescr = '   ROLLBACK.';
$strShowStatusHandler_updateDescr = '      .';
$strShowStatusHandler_writeDescr = '      .';
$strShowStatusKey_blocks_not_flushedDescr = '    ,   ,      .      Not_flushed_key_blocks.';
$strShowStatusKey_blocks_unusedDescr = '     .           ';
$strShowStatusKey_blocks_usedDescr = '     .        -  .';
$strShowStatusKey_read_requestsDescr = '       .';
$strShowStatusKey_readsDescr = '      .   Key_reads , ,    key_buffer_size  .        : Key_reads/Key_read_requests.';
$strShowStatusKey_write_requestsDescr = '       .';
$strShowStatusKey_writesDescr = '      .';
$strShowStatusNot_flushed_delayed_rowsDescr = ' ,        INSERT DELAYED.';
$strShowStatusOpen_filesDescr = '  .';
$strShowStatusOpen_streamsDescr = '   (    ).';
$strShowStatusOpen_tablesDescr = '  .';
$strShowStatusOpened_tablesDescr = '  .   Opened_tables , ,    table_cache  .';
$strShowStatusQcache_free_blocksDescr = '      .';
$strShowStatusQcache_free_memoryDescr = '     .';
$strShowStatusQcache_hitsDescr = '    .';
$strShowStatusQcache_insertsDescr = ' ,   .';
$strShowStatusQcache_lowmem_prunesDescr = ' ,             .         .        (least recently used, LRU)      ,     .';
$strShowStatusQcache_not_cachedDescr = '    (    -  QUERY_CACHE_TYPE).';
$strShowStatusQcache_queries_in_cacheDescr = ' ,   .';
$strShowStatusQcache_total_blocksDescr = '     .';
$strShowStatusReset = '';
$strShowStatusRpl_statusDescr = '   (  ).';
$strShowStatusSelect_full_joinDescr = '    .     0,       .';
$strShowStatusSelect_full_range_joinDescr = ' ,         .';
$strShowStatusSelect_range_checkDescr = '   ,         .     0,       .';
$strShowStatusSelect_rangeDescr = ' ,       .     ,    .';
$strShowStatusSelect_scanDescr = ' ,       .';
$strShowStatusSlave_open_temp_tablesDescr = '  ,       .';
$strShowStatusSlave_retried_transactionsDescr = '  (  )     .';
$strShowStatusSlave_runningDescr = '  ON,    ,    .';
$strShowStatusSlow_launch_threadsDescr = ' ,    ,  slow_launch_time .';
$strShowStatusSlow_queriesDescr = ' ,     ,  long_query_time .';
$strShowStatusSort_merge_passesDescr = ' ,   .    ,     sort_buffer_size.';
$strShowStatusSort_rangeDescr = ' ,    .';
$strShowStatusSort_rowsDescr = '  .';
$strShowStatusSort_scanDescr = ' ,    .';
$strShowStatusTable_locks_immediateDescr = '     .';
$strShowStatusTable_locks_waitedDescr = ' ,            .    ,       ,     ,     ,   .';
$strShowStatusThreads_cachedDescr = '    .          Threads_created/Connections.    ,    thread_cache_size.';
$strShowStatusThreads_connectedDescr = '     .';
$strShowStatusThreads_createdDescr = ' ,    .   Threads_created , ,     thread_cache_size (             ).';
$strShowStatusThreads_runningDescr = '   .';
$strShowTableDimension = '  ';
$strShowTables = ' ';
$strShowThisQuery = '     ';
$strSimplifiedChinese = ' ';
$strSingly = '()';
$strSize = '';
$strSlovak = '';
$strSlovenian = '';
$strSort = '';
$strSortByKey = '  ';
$strSorting = '';
$strSpaceUsage = ' ';
$strSpanish = '';
$strSplitWordsWithSpace = ',   (" ").';
$strSQL = 'SQL';
$strSQLExportType = ' ';
$strSQLImportOptions = ' SQL';
$strSQLOptions = ' SQL';
$strSQLParserBugMessage = '     SQL-. ,       .  ,         quoted text area.           MySQL.   MySQL   ,    ,   .             ,      ,    SQL      ,    .            ( CUT):';
$strSQLParserUserError = '     SQL .    MySQL   , ,    ';
$strSQLQuery = 'SQL-';
$strSQLResult = 'SQL-';
$strSQPBugInvalidIdentifer = ' ';
$strSQPBugUnclosedQuote = ' ';
$strSQPBugUnknownPunctuation = '   ';
$strStatCheckTime = ' ';
$strStatCreateTime = '';
$strStatement = '';
$strStatUpdateTime = ' ';
$strStatus = '';
$strStorageEngines = '';
$strStrucCSV = 'CSV ';
$strStrucData = '  ';
$strStrucExcelCSV = 'CSV   MS Excel';
$strStrucNativeExcel = '  MS Excel';
$strStrucOnly = ' ';
$strStructPropose = '  ';
$strStructure = '';
$strSubmit = '';
$strSuccess = ' SQL-   ';
$strSum = '';
$strSwedish = '';
$strSwitchToDatabase = '    ';
$strSwitchToTable = '   ';

$strTable = ' ';
$strTableAlreadyExists = ' %s  !';
$strTableComments = '  ';
$strTableEmpty = '  !';
$strTableHasBeenDropped = ' %s  ';
$strTableHasBeenEmptied = ' %s  ';
$strTableHasBeenFlushed = '    %s';
$strTableMaintenance = ' ';
$strTableOfContents = '';
$strTableOptions = ' ';
$strTables = '%s ()';
$strTableStructure = ' ';
$strTakeIt = '';
$strTblPrivileges = ' ,   ';
$strTempData = ' ';
$strTextAreaLength = ' -  ,<br />       ';
$strThai = '';
$strTheme = ' / ';
$strThemeDefaultNotFound = ' - %s  !';
$strThemeNoPreviewAvailable = '  .';
$strThemeNotFound = ' %s  !';
$strThisHost = ' ';
$strThreads = '';
$strThreadSuccessfullyKilled = 'Thread %s  .';
$strTime = '';
$strToggleScratchboard = 'toggle scratchboard';
$strTotal = '';
$strTotalUC = '';
$strTraditionalChinese = ' ';
$strTraditionalSpanish = ' ';
$strTraffic = '';
$strTransformation_application_octetstream__download = '      .  :    .  :          .     ,   ,          ';
$strTransformation_image_jpeg__inline = ' ,    ; : ,   (  )';
$strTransformation_image_jpeg__link = '     (direct blob download, i.e.).';
$strTransformation_image_png__inline = '. image/jpeg: inline';
$strTransformation_text_plain__external = ' LINUX:         .    .   Tidy,   HTML .   ,      libraries/transformations/text_plain__external.inc.php   ,    .   -   ,    ,  -   .     1   ,  htmlspecialchars() (  1).     1  NOWRAP,         (  1)';
$strTransformation_text_plain__formatted = '   .   .';
$strTransformation_text_plain__imagelink = '   ,    ;   -    "http://domain.com/",  -   ,  - .';
$strTransformation_text_plain__link = ' ,    ;   -    "http://domain.com/",  -   .';
$strTransformation_text_plain__substr = '   .   -  ,      (  0).   -    .   ,     .    ,     ,   . ( : ...) .';
$strTruncateQueries = '  ';
$strTurkish = '';
$strType = '';

$strUkrainian = '';
$strUncheckAll = '   ';
$strUnicode = '';
$strUnique = '';
$strUnknown = '';
$strUnselectAll = '   ';
$strUpdatePrivMessage = '   ';
$strUpdateProfileMessage = '  .';
$strUpdateQuery = ' ';
$strUpdComTab = ',    Column_comments   ';
$strUpgrade = '   %s   %s  .';
$strUsage = '';
$strUseBackquotes = '      ';
$strUsedPhpExtensions = '  PHP';
$strUseHostTable = '  ';
$strUser = '';
$strUserAlreadyExists = ' %s  !';
$strUserEmpty = '  !';
$strUserName = ' ';
$strUserNotFound = '       .';
$strUserOverview = ' ';
$strUsersDeleted = '    .';
$strUsersHavingAccessToDb = '     &quot;%s&quot;';
$strUseTables = ' ';
$strUseTextField = '  ';
$strUseThisValue = '  ';

$strValidateSQL = ' SQL';
$strValidatorError = ' SQL    . ,       PHP,   %s%s.';
$strValue = '';
$strVar = '';
$strViewDump = '  ';
$strViewDumpDatabases = '  () ';
$strViewDumpDB = '  ';

$strWebServerUploadDirectory = ',      web-';
$strWebServerUploadDirectoryError = ',     "upload"    ';
$strWelcome = '   %s';
$strWestEuropean = '-';
$strWildcard = '';
$strWindowNotFound = '      . ,           -  ';
$strWithChecked = ' :';
$strWrongUser = ' /.   .';

$strXML = 'XML';
$strXMLOptions = ' XML';

$strYes = '';

$strZeroRemovesTheLimit = ':     0 ()  .';
$strZip = '  zip';

// To translate:
$strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate

$strBinaryLog = 'Binary log';  //to translate
$strBinLogName = 'Log name';  //to translate
$strBinLogOriginalPosition = 'Original position';  //to translate
$strBinLogPosition = 'Position';  //to translate
$strBinLogServerId = 'Server ID';  //to translate
$strBrowseForeignValues = 'Browse foreign values';  //to translate
$strBufferPool = 'Buffer Pool';  //to translate
$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
$strBufferReadMisses = 'Read misses';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strBusyPages = 'Busy pages';  //to translate

$strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
$strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate

$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate

$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
$strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate

$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
$strFreePages = 'Free pages';  //to translate

$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';  //to translate
$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';  //to translate
$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
$strInvalidLDIImport = 'This plugin does not support compressed imports!';  //to translate
$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate

$strLatchedPages = 'Latched pages';  //to translate
$strLatexLabel = 'Label key';  //to translate
$strLDILocal = 'Use LOCAL keyword';  //to translate
$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate

$strMaxConnects = 'max. concurrent connections';  //to translate
$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
$strMyISAMRepairThreads = 'Repair threads';  //to translate
$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate

$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate

$strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate

$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
$strPasswordHashing = 'Password Hashing';  //to translate
$strPDFReportTitle = 'Report title';  //to translate
$strPrivDescAllPrivileges = 'Includes all privileges except GRANT.';  //to translate
$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
$strPrivDescCreateUser = 'Allows creating, dropping and renaming user accounts.';  //to translate
$strPrivDescCreateView = 'Allows creating new views.';  //to translate
$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
$strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate

$strReadRequests = 'Read requests';  //to translate

$strSelectBinaryLog = 'Select binary log to view';  //to translate
$strShowingBookmark = 'Showing bookmark';  //to translate
$strShowStatusBinlog_cache_disk_useDescr = 'The number of transactions that used the temporary binary log cache but that exceeded the value of binlog_cache_size and used a temporary file to store statements from the transaction.';  //to translate
$strShowStatusBinlog_cache_useDescr = 'The number of transactions that used the temporary binary log cache.';  //to translate
$strShowStatusHandler_discoverDescr = 'The MySQL server can ask the NDB Cluster storage engine if it knows about a table with a given name. This is called discovery. Handler_discover indicates the number of time tables have been discovered.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'The number of pages containing data (dirty or clean).';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'The number of pages currently dirty.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'The number of buffer pool pages that have been requested to be flushed.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'The number of free pages.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'The number of latched pages in InnoDB buffer pool. These are pages currently being read or written or that can\'t be flushed or removed for some other reason.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'The number of pages busy because they have been allocated for administrative overhead such as row locks or the adaptive hash index. This value can also be calculated as Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Total size of buffer pool, in pages.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'The number of "random" read-aheads InnoDB initiated. This happens when a query is to scan a large portion of a table but in random order.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'The number of sequential read-aheads InnoDB initiated. This happens when InnoDB does a sequential full table scan.';  //to translate
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'The number of logical read requests InnoDB has done.';  //to translate
$strShowStatusInnodb_buffer_pool_readsDescr = 'The number of logical reads that InnoDB could not satisfy from buffer pool and had to do a single-page read.';  //to translate
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normally, writes to the InnoDB buffer pool happen in the background. However, if it\'s necessary to read or create a page and no clean pages are available, it\'s necessary to wait for pages to be flushed first. This counter counts instances of these waits. If the buffer pool size was set properly, this value should be small.';  //to translate
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'The number writes done to the InnoDB buffer pool.';  //to translate
$strShowStatusInnodb_data_fsyncsDescr = 'The number of fsync() operations so far.';  //to translate
$strShowStatusInnodb_data_pending_fsyncsDescr = 'The current number of pending fsync() operations.';  //to translate
$strShowStatusInnodb_data_pending_readsDescr = 'The current number of pending reads.';  //to translate
$strShowStatusInnodb_data_pending_writesDescr = 'The current number of pending writes.';  //to translate
$strShowStatusInnodb_data_readDescr = 'The amount of data read so far, in bytes.';  //to translate
$strShowStatusInnodb_data_readsDescr = 'The total number of data reads.';  //to translate
$strShowStatusInnodb_data_writesDescr = 'The total number of data writes.';  //to translate
$strShowStatusInnodb_data_writtenDescr = 'The amount of data written so far, in bytes.';  //to translate
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_dblwr_writesDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_log_waitsDescr = 'The number of waits we had because log buffer was too small and we had to wait for it to be flushed before continuing.';  //to translate
$strShowStatusInnodb_log_write_requestsDescr = 'The number of log write requests.';  //to translate
$strShowStatusInnodb_log_writesDescr = 'The number of physical writes to the log file.';  //to translate
$strShowStatusInnodb_os_log_fsyncsDescr = 'The number of fsyncs writes done to the log file.';  //to translate
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'The number of pending log file fsyncs.';  //to translate
$strShowStatusInnodb_os_log_pending_writesDescr = 'Pending log file writes.';  //to translate
$strShowStatusInnodb_os_log_writtenDescr = 'The number of bytes written to the log file.';  //to translate
$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
$strShowStatusInnodb_pages_createdDescr = 'The number of pages created.';  //to translate
$strShowStatusInnodb_pages_readDescr = 'The number of pages read.';  //to translate
$strShowStatusInnodb_pages_writtenDescr = 'The number of pages written.';  //to translate
$strShowStatusInnodb_row_lock_current_waitsDescr = 'The number of row locks currently being waited for.';  //to translate
$strShowStatusInnodb_row_lock_time_avgDescr = 'The average time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_time_maxDescr = 'The maximum time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_waitsDescr = 'The number of times a row lock had to be waited for.';  //to translate
$strShowStatusInnodb_rows_deletedDescr = 'The number of rows deleted from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_insertedDescr = 'The number of rows inserted in InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_readDescr = 'The number of rows read from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_updatedDescr = 'The number of rows updated in InnoDB tables.';  //to translate
$strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
$strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
$strSQLCompatibility = 'SQL compatibility mode';  //to translate
$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
$strStorageEngine = 'Storage Engine';  //to translate
$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate

$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
$strTransactionCoordinator = 'Transaction coordinator';  //to translate
$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data. Optional first parameter specifies how often space will be added (defaults to 2 nibbles).';  //to translate
$strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate

$strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
$strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
$strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
$strVersionInformation = 'Version information';  //to translate

$strView = 'View';  //to translate
$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate

$strWriteRequests = 'Write requests';  //to translate

$strPmaWiki = 'phpMyAdmin wiki';  //to translate
$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
$strDocSQL = 'DocSQL';  //to translate
$strDocSQLOptions = 'DocSQL options';  //to translate
$strTableName = 'Table name';  //to translate
$strTableIsEmpty = 'Table seems to be empty!';  //to translate
$strDbIsEmpty = 'Database seems to be empty!';  //to translate
$strShowingPhp = 'Showing as PHP code';  //to translate
$strShowingSQL = 'Showing SQL query';  //to translate
$strDesigner = 'Designer';  //to translate
$strNumberOfTables = 'Number of tables';  //to translate
$strCreateTable  = 'Create table';  //to translate
$strCreateRelation = 'Create relation';  //to translate
$strSavePosition = 'Save position';  //to translate
$strSelectForeignKey = 'Select Foreign Key';  //to translate
$strHide         = 'Hide';  //to translate
$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
$strReload = 'Reload';  //to translate
$strSmallBigAll = 'Small/Big All';  //to translate
$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
$strMoveMenu = 'Move Menu';  //to translate
$strAngularLinks = 'Angular links';  //to translate
$strDirectLinks = 'Direct links';  //to translate
$strHideShowAll = 'Hide/Show all';  //to translate
$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
$strInternalRelationAdded = 'Internal relation added';  //to translate
$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
$strRelationDeleted = 'Relation deleted';  //to translate
$strToSelectRelation = 'To select relation, click :';  //to translate
$strExportImportToScale = 'Export/Import to scale';  //to translate
$strRecommended = 'recommended';  //to translate
$strToFromPage = 'to/from page';  //to translate
$strSelectReferencedKey = 'Select referenced key';  //to translate
$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
$strHelp = 'Help';  //to translate
$strCancel = 'Cancel';  //to translate
$strDeleteRelation = 'Delete relation';  //to translate
$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
$strStructureForView = 'Structure for view';  //to translate
$strStandInStructureForView = 'Stand-in structure for view';  //to translate
$strToggleSmallBig = 'Toggle small/big';  //to translate
$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
$strErrorRelationExists = 'Error: relation already exists.';  //to translate
$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
$strSnapToGrid = 'Snap to grid';  //to translate
$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
?>
